==> pochy-0.1.8-src.tar.gz: pochy-0.1.8-src/Skin.h <==
#if !defined(AFX_SKIN_H__F3AA9452_D0EF_424B_9B0E_62D6FFF8404F__INCLUDED_)
#define AFX_SKIN_H__F3AA9452_D0EF_424B_9B0E_62D6FFF8404F__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// Skin.h : wb_[ t@C
//

/////////////////////////////////////////////////////////////////////////////
// CSkin t[


class CSkin
{
private:
	CString m_skinIniFile;

	CString m_tasktrayIcon;
	CString m_tasktrayAnimeIcon;
	CString m_summarryViewIcons;
	CString m_summarryViewBackBmp;
	CString m_folderViewBackBmp;
	CString m_textViewBackBmp;
	CString m_mailEditViewBackBmp;
	CString m_headerViewBackBmp;
	CString m_toolbarDraftIcons;
	CString m_toolbarMainIcons;
	CString m_treeViewIcons;
	CString m_successEffectSound;

protected:

public:
	CSkin();  
	virtual ~CSkin();
	//skin.inĩ[h
	BOOL LoadSkinProfile(char *skinIniFile);
	//lget֐
	CString getSkinIniFile();
	CString getSkinIniPath();

	CString getTasktrayIcon();
	CString getTasktrayAnimeIcon();
	CString getSummarryViewIcons();
	CString getSummarryViewBackBmp();
	CString getFolderViewBackBmp();
	CString getTextViewBackBmp();
	CString getMailEditViewBackBmp();
	CString getHeaderViewBackBmp();
	CString getToolbarDraftIcons();
	CString getToolbarMainIcons();
	CString getTreeViewIcons();
	CString getSuccessEffectSound();
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_SKIN_H__F3AA9452_D0EF_424B_9B0E_62D6FFF8404F__INCLUDED_)

==> pochy-0.1.9-src.tar.gz: pochy-0.1.9-src/Skin.h <==
#if !defined(AFX_SKIN_H__F3AA9452_D0EF_424B_9B0E_62D6FFF8404F__INCLUDED_)
#define AFX_SKIN_H__F3AA9452_D0EF_424B_9B0E_62D6FFF8404F__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// Skin.h : wb_[ t@C
//

/////////////////////////////////////////////////////////////////////////////
// CSkin t[


class CSkin
{
private:
	CString m_skinIniFile;

	CString m_tasktrayIcon;
	CString m_tasktrayAnimeIcon;
	CString m_summarryViewIcons;
	CString m_summarryViewBackBmp;
	CString m_folderViewBackBmp;
	CString m_textViewBackBmp;
// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
// start
//	CString m_mailEditViewBackBmp;
	CString m_maileditViewBackBmp;
// end
	CString m_headerViewBackBmp;
// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
// start
	CString m_attachedfileViewBackBmp;
 	CString m_multipartViewBackBmp;
// end
	CString m_toolbarDraftIcons;
	CString m_toolbarMainIcons;
	CString m_treeViewIcons;
	CString m_successEffectSound;

protected:

public:
	CSkin();  
	virtual ~CSkin();
	//skin.inĩ[h
	BOOL LoadSkinProfile(char *skinIniFile);
	//lget֐
	CString getSkinIniFile();
	CString getSkinIniPath();

	CString getTasktrayIcon();
	CString getTasktrayAnimeIcon();
	CString getSummarryViewIcons();
	CString getSummarryViewBackBmp();
	CString getFolderViewBackBmp();
	CString getTextViewBackBmp();
	CString getMailEditViewBackBmp();
	CString getHeaderViewBackBmp();
// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
// start
 	CString getAttachedFileViewBackBmp();
 	CString getMultiPartViewBackBmp();
// end
	CString getToolbarDraftIcons();
	CString getToolbarMainIcons();
	CString getTreeViewIcons();
	CString getSuccessEffectSound();
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_SKIN_H__F3AA9452_D0EF_424B_9B0E_62D6FFF8404F__INCLUDED_)
